from setuptools import setup

setup(name='sub_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['sub_distributions'],
      author='Subham Kumar Gupta',
      author_email='guptasubham175@gmail.com',
      zip_safe=False)
